import { stringify } from 'qs';
import { request } from 'umi';

/**
 * 用户列表
 * @param param
 */
export async function queryUserList(param: object) {
  return request(`/web/v1/users?${stringify(param)}`);
}

/**
 * 查询用户详情信息
 * @param id
 */
export async function queryUserDetail(id: string) {
  return request(`/web/v1/users/${id}`);
}

/** 获取当前的用户信息 */
export async function currentUserInfo(param: any) {
  return request<{
    record_id: string;
    photo: string;
  }>('/web/v1/users/current', {
    method: 'GET',
    headers: { Authorization: param },
  });
}

/**
 * 新增用户信息
 * @param params
 */
export async function createUser(params: object) {
  return request(`/web/v1/users`, {
    method: 'POST',
    data: params,
  });
}

/**
 * 编辑用户信息
 * @param params
 */
export async function editUser(params: any) {
  return request(`/web/v1/users/${params.record_id}`, {
    method: 'PUT',
    data: params,
  });
}

/**
 * 启用
 * @param id
 */
export async function enableUser(id: string) {
  return request(`/web/v1/users/${id}/enable`, {
    method: 'PATCH',
  });
}

/**
 * 停用
 * @param id
 */
export async function disableUser(id: string) {
  return request(`/web/v1/users/${id}/disable`, {
    method: 'PATCH',
  });
}
